<?php

namespace Drupal\migrate_boost\Drush\Commands;

use Consolidation\AnnotatedCommand\CommandData;
use Drupal\migrate_boost\MigrateBoost;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 */
final class MigrateBoostCommands extends DrushCommands {

  /**
   * Run when drush command migrate:import is about to to be executed.
   *
   * @hook pre-command migrate:import
   */
  public function preCommandMigImport(CommandData $commandData) {
    $this->boosterEnable();
  }

  /**
   * Run when drush command migrate:rollback is about to to be executed.
   *
   * @hook pre-command migrate:rollback
   */
  public function preCommandMigRollback(CommandData $commandData) {
    $this->boosterEnable();
  }

  /**
   * Resets migrate booster and implementation cache.
   *
   * @command migrate:booster:reset
   *
   * @validate-module-enabled migrate_boost
   * @aliases mbr,migrate-booster-reset
   */
  public function boosterReset() {
    MigrateBoost::reset();
    $this->logger()->notice(dt('Migrate Boost reset'));
  }

  /**
   * Enables migrate booster and implementation cache.
   *
   * @command migrate:booster:enable
   *
   * @validate-module-enabled migrate_boost
   * @aliases mbe,migrate-booster-enable
   */
  public function boosterEnable() {
    MigrateBoost::enable();
    $this->logger()->notice(dt('Migrate Boost enabled'));
  }

}
